@@ -1,4 +1,4 @@
-GOOF----LE-4-2.0ܛ      ] 4     h/#      ] g  guile	 	g  define-module*	 	 	g  gnucash	g  report	g  owner-report		 	
+GOOF----LE-4-2.0ě      ] 4     h2#      ] g  guile	 	g  define-module*	 	 	g  gnucash	g  report	g  owner-report		 	
 g  filenameS	f  owner-report.scm	g  set-current-module	
  	 	g  process-use-modules	 	 	g  srfi	g  srfi-1	 	 	g  
 gnc-module	 	 	g  main	 	 	g  gettext	 	 	g  gnc:module-load	 f  gnucash/report/report-system	!g  standard-reports	"! 	#" 	$g  business-reports	%$ 	&% 	'f  From	(g  optname-from-date	)f  To	*g  optname-to-date	+f  Due or Post Date	,g  optname-date-driver	-f   08ae9c2e884b4f9787144f47eacd7f44	.g  employee-report-guid	/f   d7d1e53505ee4b1b82efad9eacedaea0	0g  vendor-report-guid	1f   c146317be32e4948a561ec7fc89d15c1	2g  customer-report-guid	3f  Account	4g  acct-string	5g  gnc:pagename-general	6g  
@@ -7,12 +7,12 @@ credit-header	Cf  Debits	Dg  debit-header	Ef  Amount	Fg  
 amount-header	Gg  GNC-OWNER-CUSTOMER	Hf  Customer	Ig  GNC-OWNER-EMPLOYEE	Jf  Employee	Kf  Company	Lg  owner-string	Mg  _	Nf  No valid customer selected.	Of  No valid employee selected.	Pf  No valid company selected.	Qg  invalid-selection-title-string	Rf  /This report requires a customer to be selected.	Sf  /This report requires a employee to be selected.	Tf  .This report requires a company to be selected.	Ug  invalid-selection-string	Vg  gnc:html-make-generic-warning	Wg  gnc:html-make-no-owner-warning	Xf  No valid account selected	Yf  4This report requires a valid account to be selected.	Zg  &gnc:html-make-no-valid-account-warning	[f  Vendor	\g  doctype-str	]g  make-syntax-transformer	^] 	_] 	`g  addto!	ag  macro	bg  $sc-dispatch	cb 	db 	eg  any	fMe	gg  
 syntax->datum	hg 	ig 	jg  
 datum->syntax	kj 	lj 	mg  set!	ng  cons	og  syntax-violation	po 	qo 	rf  -source expression failed to match any pattern	sg  gnc:html-table-num-rows	tg  gnc:html-table-set-row-style!	ug  set-last-row-style!	vg  date-col	wg  date-due-col	xg  num-col	yg  type-col	zg  memo-col	{g  
-credit-col	|g  	debit-col	}g  	value-col	~g  columns-used-size	g  make-vector g  gnc:option-value g  gnc:lookup-option f  Display Columns g  build-column-used g  reverse g  make-heading-list g  num-buckets g  gnc-numeric-zero g  new-bucket-vector g  decdate g  ThirtyDayDelta g  gnc:make-date-list g  make-interval-list g  incdate g  	YearDelta g  make-extended-interval-list g  xaccQueryGetLots g  QUERY-TXN-MATCH-ANY g  gnc-default-currency g  gnc:make-html-table g  
+credit-col	|g  	debit-col	}g  	value-col	~g  columns-used-size	g  make-vector g  gnc:option-value g  gnc:lookup-option f  Display Columns g  build-column-used g  reverse g  make-heading-list g  num-buckets g  gnc-numeric-zero g  new-bucket-vector g  decdate g  ThirtyDayDelta g  gnc:make-date-list g  make-interval-list g  incdate g  	YearDelta g  make-extended-interval-list g  xaccQueryGetLots g  QUERY-TXN-MATCH-ANY g  gnc:make-html-table g  
 vector-length g  	gnc:error f  "sanity check failed in find-bucket g  gnc:timepair-lt g  gnc-numeric-add-fixed g  for-each g  gnc-lot-get-balance g  gncInvoiceGetInvoiceFromLot g  postdate g  gncInvoiceGetDatePosted g  gncInvoiceGetDateDue g  gnc-numeric-zero-p g  gnc-numeric-neg g  gnc:html-table-set-col-headers! f  Current f  	0-30 days f  
 31-60 days f  
 61-90 days f  91+ days g  gnc:html-table-append-row! g  map g  gnc:make-gnc-monetary g  vector->list g  make-aging-table g  gnc-print-date f    g  gnc:make-html-table-cell/markup f  number-cell g  make-row f  Balance g  xaccTransGetCurrency f  
 normal-row f  
-alternate-row g  !gnc:html-table-append-row/markup! g  add-balance-row g  xaccTransGetTxnType g  gnc-transaction-get-date-posted g  xaccTransGetAccountValue g  xaccTransGetSplit g  gncInvoiceGetInvoiceFromTxn g  TXN-TYPE-INVOICE f  Unknown g  gnc:make-html-text g  gnc:html-markup-anchor g  gnc:invoice-anchor-text g  gncInvoiceGetTypeString g  TXN-TYPE-PAYMENT g  gnc:split-anchor-text f  Payment g  gnc:timepair-le g  gnc-get-num-action g  xaccSplitGetMemo g  gnc-numeric-negative-p g  add-txn-row g  xaccQueryGetTransactions f  __reg f  reverse? g  sort g  xaccTransOrder f  grand-total g  append f  total-label-cell f  
+alternate-row g  !gnc:html-table-append-row/markup! g  add-balance-row g  xaccTransGetTxnType g  gnc-transaction-get-date-posted g  xaccTransGetAccountValue g  xaccTransGetSplit g  gncInvoiceGetInvoiceFromTxn g  TXN-TYPE-INVOICE f  Unknown g  gnc:make-html-text g  gnc:html-markup-anchor g  gnc:invoice-anchor-text g  gncInvoiceGetTypeString g  TXN-TYPE-PAYMENT g  gnc:split-anchor-text f  Payment g  gnc:timepair-le g  gnc-get-num-action g  xaccSplitGetMemo g  gnc-numeric-negative-p g  add-txn-row g  xaccQueryGetTransactions g  xaccAccountGetCommodity f  __reg f  reverse? g  sort g  xaccTransOrder f  grand-total g  append f  total-label-cell f  
 Period Totals g  $gnc:make-html-table-cell/size/markup f  total-number-cell g  gnc:make-html-table-cell/size f  Total Credit f  	Total Due g  list->vector g  make-txn-table g  gnc:new-options g  gnc:make-simple-boolean-option g  gnc:register-option g  gnc:make-owner-option f  v f  The company for this report. g  gnc:make-internal-option f  
 owner-type g  #gnc:make-account-sel-limited-option f  w f  'The account to search for transactions. g  gnc:options-add-date-interval! f  a g  gnc:option-set-value g  relative g  today f  b f  Display the transaction date? f  c f  d f  "Display the transaction reference? f  g f  Display the transaction type? f  ha f  $Display the transaction description? f  haa f  "Display the period credits column? f  hab f  Display a period debits column? f  hb f  Display the transaction amount? g  gnc:make-string-option f  Today Date Format f  p f  <The format for the date->string conversion for today's date. g   gnc-default-strftime-date-format g  gnc:make-multichoice-option f  k f  
 Leading date.g  duedatef  Due date is leading.f  	Post Datef  Post date is leading.g  gnc:options-set-default-sectionf  Generalg  options-generatorg  ACCT-TYPE-RECEIVABLE	g  customer-options-generator
@@ -29,7 +29,7 @@ gnc:get-today@g  make-myname-tableAg  gnc:html-document-add-object!Bg
 gnc:report-idPg  gnc:html-document-set-title!Qg  gnc:html-document-set-headline!Rg  gnc:html-markupSf  !Tf  Report:Ug  gnc:owner-anchor-textVf  
 Date RangeWf   - Xg  qof-query-destroyYg  reg-rendererZg  gnc-account-nth-child[g  xaccAccountGetType\g  gnc-get-current-root-account]g  gnc-account-n-children^g  find-first-account_g  gncOwnerGetType`g  
 GNC-OWNER-JOBag  find-first-account-for-ownerbg  gnc:define-reportcg  versiondg  nameef  Customer Reportfg  report-guidgg  	menu-pathhg  gnc:menuname-business-reportsig  rendererjg  in-menu?kf  
-Vendor Reportlf  Employee Reportmg  gnc:make-report-optionsng  gnc:make-reportog  owner-report-create-internalpg  owner-report-createqg  gncOwnerNewrg  gnc:owner-from-splitsg  gnc:owner-report-createtg  gncOwnerFreeug   gnc:owner-report-create-internalvg  gnc:register-report-hookwg  call-with-deferred-observersxw yw zg  module-export!{z |z }g  current-module~} } ap C 5    hr  j  ]4	
+Vendor Reportlf  Employee Reportmg  gnc:make-report-optionsng  gnc:make-reportog  owner-report-create-internalpg  owner-report-createqg  gncOwnerNewrg  gnc:owner-from-splitsg  gnc:owner-report-createtg  gncOwnerFreeug   gnc:owner-report-create-internalvg  gnc:register-report-hookwg  call-with-deferred-observersxw yw zg  module-export!{z |z }g  current-module~} } ap C 5 hr  j  ]4	
 5 4 >  "  G   4 >  "  G  4 >  "  G  4 >  "  G  4 >  "  G  4i 
 >  "  G  4# >  "  G  4& >  "  G  '(R)*R+,R-.R/0R12R34R5i6R78R9:R;<R=>R?@RABRCDREFRGHIJK h       ] $  C $  CC          g  
 owner-type
@@ -134,7 +134,7 @@ column-vector
 dayforcurrent		* g  oldintervalreversed			*  g  filenamef  owner-report.scm
  
 		 		 	 	 	)	 	 	( 	
-	* 	 		*  g  nameg  make-extended-interval-list CR  hH   (  ] 45$  6 45$   C  "              g  current-bucket
+	* 	 		*  g  nameg  make-extended-interval-list CR    hH   (  ] 45$  6 45$   C  "              g  current-bucket
 		A g  bucket-intervals		A g  date			A g  current-bucket			)  g  filenamef  owner-report.scm
  		 		 		 		 		 		 		 		 		- 		3 		A 	 
 		A	  g  nameg  find-bucket C  h(      ]4L 
@@ -149,26 +149,26 @@ apply-invoice C 	     hp   K  ]!4 5H4 5L &  45"
  		o   CM   h   a   ]L  6      Y       g  entry
 		
   g  filenamef  owner-report.scm
-		
-	
+		
+	
  		
-   C  h     ]=4545 45 45 45 	HO 
-O 
+   C  h     ]64545 45 45 	HO 
+O 
 Q 
 
-Q 4	
-O >  "  G  4	4
-545454545 >  "  G  4	44O 4555>  "  G  	C         g  options
-	  g  query	  g  bucket-intervals		  g  reverse?		  g  	date-type		  g  lots		  g  buckets		  g  payments		  g  currency		  g  table			  g  find-bucket	
-	;  g  
-apply-invoice		;   g  filenamef  owner-report.scm
+Q 4	O >  "  G  4
+	454
+5454545 >  "  G  4	44O 4555>  "  G  	C        g  options
+	  g  query	  g  bucket-intervals		  g  reverse?		  g  	date-type		  g  currency		  g  lots		  g  buckets		  g  payments		  g  table			  g  find-bucket	
+	4  g  
+apply-invoice		4   g  filenamef  owner-report.scm
  
 	 		 	
-	 		 		 		 		J 		i 		n 		r 		t 		u 		y 		{ 		| 	  	
+	 		 		 		C 		b 		g 		k 		m 		n 		r 		t 		u 		y 	
+	{ 		| 	  	
   	  	  	
-  	 	 	
- 	  	  	 	 	 	 	 	 	 	 "	 	  g  nameg  make-aging-table CRvwxyz{|} 
-    h     , 	3 
+  	  	  	 	 	 	 	 	 	 	 !	 	  g  nameg  make-aging-table CRvwxyz{|} 
+h     , 	3 
 H	4 5$  45J	K	"   4 5$  ,$  
 
 $  "  45"  J	K	"   4 5$  J	K	"   4 5$  J	K	"   4 5$  J	K	"   4 5$  4	
@@ -178,13 +178,13 @@ $  "  45"  J	K	"   4 5$  J	K	"   4 5$  J	K	"   4 5
 column-vector
 	  g  date	  g  due-date		  g  num		  g  type-str		  g  memo		  g  monetary		  g  credit		  g  debit		  g  row-contents			   
 g  filenamef  owner-report.scm
-
-					
-						 		%		/		5			:	$	;		?	
-	A	
-	F	
-	R	
-	W		\		f		m		r		|	 	 	 	 	 	 	  		  	*  		 	 !	 !	 #		 #	* #		 "	 $	 $	 &		 &	* &		 %	 -	 		  g  nameg  make-row CR}M 
+
+					
+						 		%		/		5			:	$	;		?	
+	A	
+	F	
+	R	
+	W		\		f		m		r		|	 	 	 	 	 	 	 		 	* 		 	  	  	 "		 "	* "		 !	 #	 #	 %		 %	* %		 $	 -	 		  g  nameg  make-row CR}M 
 h   E  ]HHJ$  "  K45$  45$  "  o44544555	J$  	"  
 H4 J45>  "  G  JKJ$  	"  
 K"   JC =      g  table
@@ -198,12 +198,12 @@ column-vector
 start-date		
   g  total		
   g  row		f  g  	row-style		f   	g  filenamef  owner-report.scm
-/
-	0		2		3	
-	"3		#3	,	-3		24		;4	9	<4	<	@4	?	B4	<	D4	J	E5		H5	(	R5		T5	J	V5	M	X4		^6		`6	"	f6	/	f4		k7	
-	r7	=	}7	
- 8	 8	
- 9	 9	' 9	4 9	
+.
+	/		1		2	
+	"2		#2	,	-2		23		;3	9	<3	<	@3	?	B3	<	D3	J	E4		H4	(	R4		T4	J	V4	M	X3		^5		`5	"	f5	/	f3		k6	
+	r6	=	}6	
+ 7	 7	
+ 8	 8	' 8	4 8	
  !	 	  g  nameg  add-balance-row CRM        h    , 	3 HH45	45
 H45H4
 5
@@ -223,14 +223,14 @@ column-vector		 g  odd-row?		 g  printed?		 g  reverse?
 start-date		 g  total		 g  type			 g  date	
 	 g  due-date		! g  value		, g  split	
 	6 g  invoice		? g  currency		H g  type-str	  g  row	^ g  	row-style	^  g  filenamef  owner-report.scm
-C
-	E		E		F		E		$H		,E		/I		6E		9J		?E		BK		HE		ON		SM		YO		ZT		^T		`T		eP		hQ			kR	
-	rS	
-	zQ			|P	 U	 M	 V	 W		 X	
- X	( X	+ X	( W		 V	 Y	
- Y	 Y	
- E	 \	 ]	 ]	 _	 _	 c	 c	 f	 g	 g	
- i	 i	7j	k	l	%l	'm	6,m	5n	?n	@o	No	6Pi	Vq	Xq	 ^q	-^i	cs	jt	us	v	v	y	 I			  g  nameg  add-txn-row CR     h   u   ]
+B
+	D		D		E		D		$G		,D		/H		6D		9I		?D		BJ		HD		OM		SL		YN		ZS		^S		`S		eO		hP			kQ	
+	rR	
+	zP			|O	 T	 L	 U	 V		 W	
+ W	( W	+ W	( V		 U	 X	
+ X	 X	
+ D	 [	 \	 \	 ^	 ^	 b	 b	 e	 f	 f	
+ h	 h	7i	j	k	%k	'l	6,l	5m	?m	@n	Nn	6Ph	Vp	Xp	 ^p	-^h	cr	js	ur	u	u	x	 I			  g  nameg  add-txn-row CR     h   u   ]
 4 5C  m       g  a
 		 g  b		  g  filenamef  owner-report.scm
 			-	
@@ -241,7 +241,7 @@ start-date		 g  total		 g  type			 g  date
 	M	
 	S		T		Y	$	\		`		a		h	5	k		m		r		y	7	|		~	 	 	3 	 	
  	 	
-  	    C{|M}zyxwv~ .h    ]V454 545 45 45 45 45 44 	
+  	    C{|M}zyxwv~ .h    ]V454 545 45 45 4545 44 	
 55
 H
 H	HH445>  "  G  4
@@ -252,26 +252,25 @@ J>  "  G  J(  "  4JJJJ>  "  G  45$  "  
 HH45$  "444J
 J	555JK"   45$  44J	55JK"   45$  44J
 55JK"   4 5$  	JK"   4!5$  	JK"   4"5$  	JK"   4#5$  	JK"   4$5$  	JK"   J	$  4%J&5JK"   J5>  "  G  "   45$  _4444'J5$  4(5"  4)55 4454J55 5>  "  G  "   4*4+5544%,4- 
-55 >  "  G  C     
+55 >  "  G  C 
       g  options
 	 g  query	 g  acc		 g  
-start-date		 g  end-date		 g  	date-type		 g  txns		; g  used-columns		; g  total		; g  debit			; g  credit	
-	; g  currency		; g  table		; g  reverse?	
-	; g  printed?		q  g  odd-row?		q  g  t	   g  row-contents	 g  pre-span	 g  interval-vec	  g  filenamef  owner-report.scm
-}
-	~										"		'		,		/	 	5	;	7		9	 	;		;~		L		Q		\		e		o		q		v	 	 	 	* 	 	 	 	& 	 	 	 	 	 							
-			
-		
-$	%	
-*	*4	
-6	
-;	#@	
-J	K	
-Q	R	
-\	
-a	#f	
-p	q	
-w	x	
+start-date		 g  end-date		 g  	date-type		 g  txns		= g  used-columns		= g  total		= g  debit			= g  credit	
+	= g  currency		= g  table		= g  reverse?	
+	= g  printed?		s  g  odd-row?		s  g  t	   g  row-contents	 g  pre-span	 g  interval-vec	  g  filenamef  owner-report.scm
+|
+	}		~								"		)		.		1	 	7	;	9		;	 	=		=}		N		S		^		g		q		s		x	 	 	 	* 	 	 	 	& 	 	 	 	 											
+	 	
+&	'	
+,	*6	
+8	
+=	#B	
+L	M	
+S	T	
+^	
+c	#h	
+r	s	
+y	z	
 	
 	$	
 		1	"	
@@ -279,7 +278,8 @@ start-date		 g  end-date		 g  	date-type		 g  txns		;
 		0	!	
 		5	&	
 		1	"	
-		/	P	_	/			(	2	3	9	:	=	A	B	L	M	Q	S	X	\	^	`	c	d	h	p	q	{	~						'					
+		/	P	_	/
+			*	4	5	;	<	?	C	D	N	O	S	U	Z	^	`	b	e	f	j	r	s	}							'					
 	
 	
 		 		  g  nameg  make-txn-table CR6L       h   M   ] C    E       g  filenamef  owner-report.scm
@@ -305,45 +305,47 @@ new-option	6O g  
 new-option	s  g  filenamef  owner-report.scm
 
 			
-			#		+		6		9							5		:	%	B	?	D		K		K		N		e		i		k	%	o		o		r	 	 	? 	 	 	 	 	 	% 	 	 	 	 	( 	 	 	 	 	 	 	 	 			
-			!		!	$	;	?	C	E	H	H
-	K	b	f	j	l	o	o	r					
-										"	#	$	$	"	!		'	(	)	)	
-'	&		%,	+-	-.	/.	0/	6,	6+	9	P2	X5	Z6	\7	^9	
-`9	b9	*e9	g:	
-i:	k:	,n:	q8	s2	s1	v	<	<	8<	 z		  g  nameg  options-generator CRG    h   |   ]  6  t       g  filenamef  owner-report.scm
-@
-		A		A	 		
+			#		+		6		9							5		:	%	B	?	D		K		K		N		e		i		k	%	o		o		r	 	 	? 	 	 	 	 	 	% 	 	 	  	  	(  	 	 	 	 	 	 	 	 				
+	
+	!	!	$	;
+	?	C	E	H
+	H	K	b	f	j	l	o	o	r					
+										!	"	#	#	!	 		&	'	(	(	
+&	%		%+	+,	--	/-	0.	6+	6*	9	P1	X4	Z5	\6	^8	
+`8	b8	*e8	g9	
+i9	k9	,n9	q7	s1	s0	v	;	;	8;	 z		  g  nameg  options-generator CRG    h   |   ]  6  t       g  filenamef  owner-report.scm
+?
+		@		@	 		
   g  nameg  customer-options-generator C	R
    h   z   ]  6  r       g  filenamef  owner-report.scm
-C
-		D		D	 		
+B
+		C		C	 		
   g  nameg  vendor-options-generator CR
 I      h   |   ]  6  t       g  filenamef  owner-report.scm
-F
-		G		G	 		
+E
+		F		F	 		
   g  nameg  employee-options-generator C
 R       h   f   ] L C       ^       g  c
 			  g  filenamef  owner-report.scm
-K		K	!	K	 			   C     h   f   ] L C       ^       g  c
+J		J	!	J	 			   C     h   f   ] L C       ^       g  c
 			  g  filenamef  owner-report.scm
-M		M	-	M	( 			   C h`   #  ] (  C4LO  54LO  5(  "  45(  "  L 4L56        g  chars
+L		L	-	L	( 			   C h`   #  ] (  C4LO  54LO  5(  "  45(  "  L 4L56        g  chars
 		^ g  rest	'	: g  first	:	^ g  rest		:	^  g  filenamef  owner-report.scm
-Q		R		
-S		K		M		'M		/N		0O	
-	7P	
-	:T		AV		MW		OW	*	VX		^V	
+P		Q		
+R		J		L		'L		/M		0N	
+	7O	
+	:S		AU		MV		OV	*	VW		^U	
  		^  g  nameg  line-helper C       h       ]O Q 4 56       g  string
 		  g  	character		  g  replace-string			  g  line-helper			   g  filenamef  owner-report.scm
-I
-	Y		 Y	 		 	  g  nameg  
+H
+	X		 X	 		 	  g  nameg  
 string-expand CR !"#        h   g  ]44554  >  "  G  4 	
  >  "  G  4 	 >  "  G  4 
 >  "  G  4 
 >  "  G  4 45 >  "  G   C     _      g  q
 	  g  owner	  g  account		  g  end-date		  g  guid		   g  filenamef  owner-report.scm
-[
-	\		\	#	\		\		^		 `		)^		2c		?e		Hc		Qg		`i		ig		rm	 n	 o	 o	 o	 	 	  g  nameg  setup-query C$R%&'()*+,u-./       h     ]	45 4
+Z
+	[		[	#	[		[		]		 _		)]		2b		?d		Hb		Qf		`h		if		rl	 m	 n	 n	 n	 	 	  g  nameg  setup-query C$R%&'()*+,u-./       h     ]	45 4
  
  
  >  "  G  44	4
@@ -351,9 +353,9 @@ string-expand CR !"#        
 5 >  "  G  4 >  "  G  4
  >  "  G  C             g  owner
 	  g  table	   g  filenamef  owner-report.scm
-r
-	s		s		
-t		u		v		v		v		w		w		 w		"x		$x		(x		-t		6y		;|		>|		H|	J	J|		M{		Ry		[}		a		d		i}		r		x		z		|		~	 	 	 "	   g  nameg  make-owner-table C0R12     h(      ] 45445 5 6           g  table
+q
+	r		r		
+s		t		u		u		u		v		v		 v		"w		$w		(w		-s		6x		;{		>{		H{	J	J{		Mz		Rx		[|		a~		d~		i|		r		x		z		|		~	 	 	 "	   g  nameg  make-owner-table C0R12     h(      ] 45445 5 6           g  table
 		$ g  label		$ g  date			$  g  filenamef  owner-report.scm
 
 			
@@ -408,33 +410,34 @@ start-date		e g  section		q  g  name		q  g  end-date	 
 		
 										"		.		0		6		9		<		B		G		J		M		Y		[		c		e		e		h		k		q		v		y		|	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 	 			"	5
 	9	<	9			
-"	#	)	5*	:2	4	:	;	@	E	M	R	_	w										%								$															 						!		"	,	C.	0	5		:	C	H		S	\	n	s		v	
-y	}							
-												 	  g  nameg  reg-renderer CYRZ[\]   hp     ])"  ;$  C4545 &  C"45 45
+"	#	)	5*	:2	4	:	;	@	E	M	R	_	w										%								$															 						!		"	,	C.	0	5		:	C	H		S	\	n	s 		v	
+y	}							
+ 				
+							 	  g  nameg  reg-renderer CYRZ[\]   hp     ])"  ;$  C4545 &  C"45 45
 $  
 "C            g  type
 		j g  account		A g  num			A g  index			A g  
 this-child			A g  account-type		#	A g  current-root	F	j g  num-accounts		O	j  g  filenamef  owner-report.scm
-
-															#		-		7	"	A	
-	B		F		I		O		U		Y		h		i	 		j  g  nameg  find-first-account C^R_G^
+
+															#		-		7	"	A	
+	B		F		I		O		U		Y		h		i	 		j  g  nameg  find-first-account C^R_G^
 I`a       hX   3  ]	44 55$  6$  6$  6	$  
 4 56C     +      g  owner
 		S g  type		S  g  filenamef  owner-report.scm
-
-	 		 		 		 		"		!		#		$%		(!		.&		3(		7!		=)		B+		F!		I,	%	Q,		R/	 		S  g  nameg  find-first-account-for-owner CaR4bicdef2ighi 	iiYij>  "  G  4bicdkf0ighi iiYij>  "  G  4bicdlf.ighi 
+
+									!		 		"		$$		( 		.%		3'		7 		=(		B*		F 		I+	%	Q+		R.	 		S  g  nameg  find-first-account-for-owner CaR4bicdef2ighi 	iiYij>  "  G  4bicdkf0ighi iiYij>  "  G  4bicdlf.ighi 
 iiYij>  "  G  m6L4n    h`   l  ]4 54455454>  "  G  4>  "  G   6      d      g  report-guid
 		Z g  owner		Z g  account			Z g  
 owner-type			Z g  options				Z g  owner-op			Z g  
 account-op		(	Z  g  filenamef  owner-report.scm
-L
-	M			M		N		N	5	N		M		O		(M		+Q		?R		ZS	 
+K
+	L			L		M		M	5	M		L		N		(L		+P		?Q		ZR	 
 		Z	  g  nameg  owner-report-create-internal CoR_Go20I. 
      hX     ]
 44 55$   6$   6$  	 6C             g  owner
 		Q g  account		Q g  type			Q  g  filenamef  owner-report.scm
-U
-	V		V		V		V		X		W		%Y		*[		.W		:\		?^		CW		O_	 		Q	  g  nameg  owner-report-create CpRqrst hH     , 3 45 45		H
+T
+	U		U		U		U		W		V		%X		*Z		.V		:[		?]		CV		O^	 		Q	  g  nameg  owner-report-create CpRqrst hH     , 3 45 45		H
 	(  "  4	 5K
 4>  "  G  J
 C        g  account
@@ -442,11 +445,11 @@ C        g  account
 credit-string			F g  
 temp-owner			F g  owner				F g  res	
 		F  g  filenamef  owner-report.scm
-c
-	g		g		h		g		"k		'l		1l		2n	 
+b
+	f		f		g		f		"j		'k		1k		2m	 
 		F	  g  nameg   gnc:owner-report-create-internal CuR4viiui>  "  G  4vi
 iui>  "  G  y|     h   C   ] 45 6   ;       g  filenamef  owner-report.scm
-w
+v
  		
    C6   b      g  m
 	
@@ -503,36 +506,37 @@ iui>  "  G  y|     h   C   ] 45 6   ;       g  fi
  
  
 # 
-'
-*/
-1rC
->}
-I8
-I@
-JC
-K0F
-NI
-QS[
-Sr
-U
+'
+*.
+1ZB
+>|
+I 
+I?
+JnB
+KE
+NH
+Q;Z
+Sq
+T
 V
 Z
 [
-g
-i
-k
-k1
-k2k3k3	k4k5k5	k6k7k8k1
-k:
-k;k<k<	k=k>k>	k?k@lAl
-:
-lC
-lDl"El%E	l(Fl/Gl7G	l:HlBIlJJlPC
-nHL
-oU
-qc
-qq
-rt
-rw
- z	r
+gm
+i
+kw
+kx0
+k1k2k2	k3k4k4	k5k6k7k0
+k9
+k:k;k;	k<k=k=	k>k?k@k9
+kB
+lCl
+Dl
+D	lElFlF	l"Gl*Hl2Il8B
+n0K
+oT
+qb
+qp
+qs
+r}v
+ z	r}
    C6 
\ No newline at end of file
